@@ -24,20 +24,19 @@ def load(filename):
     stulist = []
     # 导入学生信息
     if os.path.exists(filename):
-        try:
-            with open(filename, 'r', encoding='utf-8') as fp:
-                while True:
-                    fs = fp.readline().strip('\n')
-                    if not fs:
-                        break
+        with open(filename, 'r', encoding='utf-8') as fp:
+            while True:
+                fs = fp.readline().strip('\n')
+                if not fs:
+                    break
+                else:
+                    stu = Student(*fs.split(','))
+                    if __exists(stulist,stu.no):
+                        print('该学号已存在')
                     else:
-                        stu = Student(*fs.split(','))
-                        if __exists(stu.no):
-                            print('该学号已存在')
-                        else:
-                            stulist.append(stu)
-            print('导入完毕')
-        except:
-            print('error...')  # 要导入的文件不是utf-8编码，或是字段数不匹配等
+                        stulist.append(stu)
+        print('导入完毕')
     else:
         print('要导入的文件不存在')
+
+    return stulist
